<?php
/*
Plugin Name: Elementor GIF Widget
Description: Adds a custom widget to Elementor for inserting GIF files into pages.
Version: 1.0
Author: Rajeevdaz
Author URI: https://rajeevdaz.com/
*/

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

/**
 * Add custom links (author name and YouTube link) to the plugin row on the plugins page.
 *
 * @param array $links Existing plugin links.
 * @param string $file Plugin file path.
 * @return array Updated links.
 */
function add_custom_plugin_links( $links, $file ) {
    // Make sure it's for this plugin
    if ( plugin_basename( __FILE__ ) === $file ) {
        // Add YouTube video tutorials link
        $youtube_link = '<a href="https://youtube.com/@Rajeevdaz" target="_blank">Video tutorials</a>';
        
        // Append the custom links
        $links[] = $youtube_link;
    }
    return $links;
}
add_filter( 'plugin_row_meta', 'add_custom_plugin_links', 10, 2 );

/**
 * Checks if Elementor is loaded, and if so, registers the GIF widget.
 */
function register_gif_widget() {
    // Ensure Elementor is loaded
    if ( ! did_action( 'elementor/loaded' ) ) {
        return;
    }

    // Include the widget class file
    require_once( __DIR__ . '/widgets/gif-widget.php' );

    // Register the widget
    \Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \Elementor_GIF_Widget() );
}

/**
 * Adds actions to initialize the widget after Elementor is loaded.
 */
function initialize_gif_widget_plugin() {
    // Only proceed if Elementor is active
    if ( did_action( 'elementor/loaded' ) ) {
        // Register the widget when widgets are registered in Elementor
        add_action( 'elementor/widgets/widgets_registered', 'register_gif_widget' );
    }
}
add_action( 'plugins_loaded', 'initialize_gif_widget_plugin' );
