<?php
use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Elementor_GIF_Widget extends Widget_Base {

    public function get_name() {
        return 'gif_widget';
    }

    public function get_title() {
        return __( 'GIF Widget', 'plugin-name' );
    }

    public function get_icon() {
        return 'eicon-image'; // You can change this icon if needed
    }

    public function get_categories() {
        return [ 'general' ]; // Define category for the widget
    }

   protected function register_controls() {
    $this->start_controls_section(
        'content_section',
        [
            'label' => esc_html__( 'Content', 'plugin-name' ),
            'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
        ]
    );

    $this->add_control(
        'gif_media',
        [
            'label' => esc_html__( 'Select GIF', 'plugin-name' ),
            'type' => \Elementor\Controls_Manager::MEDIA,
            'media_types' => [ 'image' ],
            'default' => [
                'url' => '',
            ],
        ]
    );

    $this->end_controls_section();
}

    protected function render() {
    $settings = $this->get_settings_for_display();
    $gif_url = esc_url( $settings['gif_media']['url'] );

    if ( ! empty( $gif_url ) && $this->is_gif( $gif_url ) ) {
        echo '<img src="' . $gif_url . '" alt="' . esc_attr__( 'GIF Image', 'plugin-name' ) . '" style="width: 100%; height: auto; image-rendering: -webkit-optimize-contrast; image-rendering: crisp-edges; image-rendering: pixelated;" loading="lazy" />';
    } else {
        echo esc_html__( 'Please select a valid GIF file.', 'plugin-name' );
    }
}

/**
 * Check if the provided URL is a GIF image.
 *
 * @param string $url The URL to check.
 * @return bool True if the URL is a GIF, false otherwise.
 */
private function is_gif( $url ) {
    $file_info = pathinfo( $url );
    return isset( $file_info['extension'] ) && strtolower( $file_info['extension'] ) === 'gif';
}

}
